qx.Class.define("pf.base.Radiator",
{
    extend: pf.base.Species,
    
    members: {
        _n_l: 1,
        _n_u: 2,
        
        getZcore: function()
        {
            return this._q + 1;
        },
        
        getN_u: function()
        {
            return this._n_u;
        },
        
        getN_l: function()
        {
            return this._n_l;
        },
        
        setN_u: function(n_u)
        {
            if (n_u < 2) {
                return false;
            } else {
                this._n_u = n_u;
                
                if (this._n_l >= this._n_u) {
                    this._n_l = this._n_u - 1;
                }
            }
        },
        
        setN_l: function(n_l)
        {
            if (n_l < 1) {
                return false;
            } else {
                this._n_l = n_l;
                
                if (this._n_l >= this._n_u) {
                    this._n_u = this._n_l + 1;
                }
            }
        },

        getTransitionEnergy: function()
        {
            var Z_core = this.getZcore();
            
            return pf.base.Bohr.transitionEnergy(Z_core,
                this._m, this._n_u, this._n_l);
        },
        
        getFineStructure: function()
        {
            var Z_core = this.getZcore();
            
            return pf.base.Bohr.transitionFineStructure(Z_core,
                this._n_u, this._n_l);
        },
        
        getMinEnergyDistance: function()
        {
            var n = this._n_u;
            var Z_core = this.getZcore();
            
            return pf.base.Bohr.transitionEnergy(Z_core, this._m, n + 1, n);
        },

        getNaturalWidth: function()
        {
            var Z_core = this.getZcore();
            
            return pf.base.Bohr.LymanA(Z_core, this._n_u) +
                   pf.base.Bohr.LymanA(Z_core, this._n_l);
        },
        
        getOscillatorStrength: function()
        {
            return pf.base.Bohr.oscillatorStrength(this._n_u, this._n_l);
        },
        
        getEinsteinA: function()
        {
            var Z_core = this.getZcore();
            
            return pf.base.Bohr.EinsteinA(Z_core,
                this._m, this._n_u, this._n_l);
        },
        
        getDopplerHwhm: function()
        {
            var v   = this.getThermalVelocity();
            var nu  = this.getTransitionEnergy();
            
            return Math.sqrt(2*Math.log(2))*nu*v/pf.base.Bohr.c;
        },

        getClassicalIonizationField: function()
        {
            var Z_core = this.getZcore();
            
            return pf.base.Bohr.classicalIonizationField(Z_core, this._n_u);
        },
        
        getInglisTellerField: function()
        {
            var Z_core = this.getZcore();
            var n = this._n_u;
            
            return Math.pow(Z_core, 3)*
                (2*n + 1)/(6*Math.pow(n, 4)*(n + 1)*(n + 1));
        }
        
    }
});
